@@ -7,7 +7,7 @@ use FindBin;
 
 
 ## we delete all files we don't need in this directory. Be careful in case users try running it somewhere else, outside this dir.
-chdir $FindBin::Bin or die "error, cannot cd to $FindBin::Bin";
+chdir $FindBin::RealBin or die "error, cannot cd to $FindBin::RealBin";
 
 
 
@@ -20,15 +20,17 @@ my @files_to_keep = qw (cleanme.pl
                         
                         test_PE_normalization.w_base_cov_stats.sh
                         test_PE_normalization.sh
+test_PE_normalization.mult_read_sets.sh
                         
                         );
 
 my %keep = map { + $_ => 1 } @files_to_keep;
 
 
-`rm -rf tmp_normalized_reads/`;
-`rm -rf single_tmp_norm_reads/`;
-`rm -rf tmp_PE_norm_dir`;
+`rm -rf ./tmp_normalized_reads/`;
+`rm -rf ./single_tmp_norm_reads/`;
+`rm -rf ./tmp_PE_norm_dir`;
+`rm -rf ./test_multi_read_sets_norm_outdir/`;
 
 
 foreach my $file (<*>) {
